@@ -1,10 +1,10 @@
 #' @export
-object_defaults.r6class <- function(x) {
+object_defaults.r6class <- function(x, block) {
   r6on <- roxy_meta_get("r6", TRUE)
   if (isTRUE(r6on)) {
     list(
-      roxy_tag("docType", NULL, NULL),
-      roxy_tag(".r6data", NULL, extract_r6_data(x$value))
+      roxy_generated_tag(block, "docType", NULL),
+      roxy_generated_tag(block, ".r6data", extract_r6_data(x$value))
     )
   } else {
     NextMethod()
@@ -45,13 +45,18 @@ extract_r6_methods <- function(x) {
     function(m) {
       ref <- utils::getSrcref(m)
       if (is.null(ref)) {
-        name <- x$classname %||% NA
-        stop(
-          "R6 class ", if (!is.na(name)) paste0("(", name, ") "),
-          "without source references. ",
-          "If you use the `installed` load method in `DESCRIPTION`, then ",
-          "try re-installing the package with option '--with-keep.source'. ",
-          "E.g. `install.packages(..., INSTALL_OPTS = \"--with-keep.source\")`."
+        name <- x$classname %||% "unknown"
+
+        cli::cli_abort(
+          c(
+            "R6 class {.cls {name}} lacks source references.",
+            i = paste0(
+              "If you are using the `installed` load method in {.file DESCRIPTION}, then ",
+              "try re-installing the package with option '--with-keep.source', e.g. ",
+              "{.code install.packages(..., INSTALL_OPTS = \"--with-keep.source\")}."
+            )
+          ),
+          call = NULL
         )
       }
       utils::getSrcLocation(ref)
@@ -68,6 +73,7 @@ extract_r6_methods <- function(x) {
   methods <- data.frame(
     stringsAsFactors = FALSE,
     type = if (length(method_loc)) "method" else character(),
+    class = if (length(method_loc)) x$classname %||% NA_character_ else character(),
     name = unname(method_nms),
     file = unname(method_fnm),
     line = unname(method_loc),
@@ -91,6 +97,7 @@ add_default_method_data <- function(obj, methods) {
     rec <- data.frame(
       stringsAsFactors = FALSE,
       type = defaults[[mname]]$type %||% "method",
+      class = defaults[[mname]]$class %||% obj$classname %||% "unknown",
       name = defaults[[mname]]$name %||% mname,
       file = defaults[[mname]]$file %||% NA_character_,
       line = defaults[[mname]]$line %||% NA_integer_,
@@ -108,6 +115,7 @@ extract_r6_fields <- function(x) {
     stringsAsFactors = FALSE,
     type = rep("field", length(field_nms)),
     name = as.character(field_nms),
+    class = rep(x$classname %||% NA_character_, length(field_nms)),
     file = rep(NA, length(field_nms)),
     line = rep(NA, length(field_nms)),
     formals = I(replicate(length(field_nms), NULL))
@@ -120,6 +128,7 @@ extract_r6_bindings <- function(x) {
     stringsAsFactors = FALSE,
     type = if (length(bind_nms)) "active" else character(),
     name = as.character(bind_nms),
+    class = rep(x$classname %||% NA_character_, length(bind_nms)),
     file = rep(NA, length(bind_nms)),
     line = rep(NA, length(bind_nms)),
     formals = I(replicate(length(bind_nms), NULL))
