@@ -14,14 +14,12 @@ roxy_tag_parse.roxy_tag_examplesIf <- function(x) {
     }
   )
 
-  dontshow <- paste0(
-    "\\dontshow{if (",
-    condition,
-    ") (if (getRversion() >= \"3.4\") withAutoprint else force)(\\{ # examplesIf}"
-  )
-
   x$raw <- paste(
-    c(dontshow, lines[-1], "\\dontshow{\\}) # examplesIf}"),
+    c(
+      paste0("\\dontshow{if (", condition, ") withAutoprint(\\{ # examplesIf}"),
+      lines[-1],
+      "\\dontshow{\\}) # examplesIf}"
+    ),
     collapse = "\n"
   )
 
@@ -77,6 +75,7 @@ format.rd_section_examples <- function(x, ...) {
 #' by R core.
 #'
 #' @keywords internal
+#' @export
 #' @examples
 #' # In examples we automatically escape Rd comments (%):
 #' 100 %% 30
