@@ -139,14 +139,15 @@ test_that("short and sweet links work", {
     foo <- function() {}")[[1]]
   expect_equivalent_rd(out1, out2)
 
-  expect_snapshot_warning(
-    out1 <- roc_proc_text(rd_roclet(), "
+  block <- "
     #' Title
     #'
     #' Description, see [name words][stringr::bar111].
     #' @md
-    foo <- function() {}")[[1]]
-  )
+    foo <- function() {}
+  "
+  expect_snapshot(out1 <- roc_proc_text(rd_roclet(), block)[[1]])
+
   out2 <- roc_proc_text(rd_roclet(), "
     #' Title
     #'
@@ -183,8 +184,8 @@ test_that("short and sweet links work", {
   out1 <- roc_proc_text(rd_roclet(), "
     #' Title.
     #'
-    #' In another package: [and this one][devtools::document].
-    #' [name words][devtools::document].
+    #' In another package: [and this one][desc::desc].
+    #' [name words][desc::desc].
     #'
     #' @md
     #' @name markdown-test
@@ -192,8 +193,8 @@ test_that("short and sweet links work", {
   out2 <- roc_proc_text(rd_roclet(), "
     #' Title.
     #'
-    #' In another package: \\link[devtools:document]{and this one}.
-    #' \\link[devtools:document]{name words}.
+    #' In another package: \\link[desc:desc]{and this one}.
+    #' \\link[desc:desc]{name words}.
     #'
     #' @name markdown-test
     foo <- function() {}")[[1]]
@@ -209,13 +210,13 @@ test_that("a weird markdown link bug is fixed", {
     #' Link to a function: [roxygenize()].
     #' Link to an object: [roxygenize] (we just treat it like an object here).
     #'
-    #' Link to another package, function: [devtools::document()].
-    #' Link to another package, non-function: [devtools::document].
+    #' Link to another package, function: [desc::desc()].
+    #' Link to another package, non-function: [desc::desc].
     #'
     #' Link with link text: [this great function][roxygenize()],
     #' [`roxygenize`][roxygenize()], or [that great function][roxygenize].
     #'
-    #' In another package: [and this one][devtools::document].
+    #' In another package: [and this one][desc::desc].
     #'
     #' @md
     #' @name markdown-test
@@ -228,13 +229,13 @@ test_that("a weird markdown link bug is fixed", {
     #' Link to a function: \\code{\\link[=roxygenize]{roxygenize()}}.
     #' Link to an object: \\link{roxygenize} (we just treat it like an object here).
     #'
-    #' Link to another package, function: \\code{\\link[devtools:document]{devtools::document()}}.
-    #' Link to another package, non-function: \\link[devtools:document]{devtools::document}.
+    #' Link to another package, function: \\code{\\link[desc:desc]{desc::desc()}}.
+    #' Link to another package, non-function: \\link[desc:desc]{desc::desc}.
     #'
     #' Link with link text: \\link[=roxygenize]{this great function},
     #' \\code{\\link[=roxygenize]{roxygenize}}, or \\link[=roxygenize]{that great function}.
     #'
-    #' In another package: \\link[devtools:document]{and this one}.
+    #' In another package: \\link[desc:desc]{and this one}.
     #'
     #' @name markdown-test
     #' @keywords internal
@@ -453,8 +454,7 @@ test_that("markup in link text", {
 })
 
 test_that("linking to self is unqualified", {
-  old <- roxy_meta_set("current_package", "myself")
-  on.exit(roxy_meta_set("current_package", old), add = TRUE)
+  local_roxy_meta_set("current_package", "myself")
   rd <- markdown("foo [myself::fun()] and [myself::obj] bar")
   expect_equal(
     rd,
@@ -477,3 +477,41 @@ test_that("percents are escaped in link targets", {
     foo <- function() {}")[[1]]
   expect_equivalent_rd(out1, out2)
 })
+
+test_that("resolve_link_package", {
+  rm(list = ls(envir = mddata), envir = mddata)
+  expect_snapshot({
+    resolve_link_package("roxygenize", "roxygen2", test_path("testMdLinks2"))
+    resolve_link_package("UseMethod", "roxygen2", test_path("testMdLinks2"))
+    resolve_link_package("cli_abort", "roxygen2", test_path("testMdLinks2"))
+  })
+
+  tag <- roxy_tag("title", NULL, NULL, file = "foo.R", line = 10)
+  expect_snapshot({
+    resolve_link_package("aa3bc042880aa3b64fef1a9", "roxygen2", test_path("testMdLinks2"), list(tag = tag))
+  })
+  # re-exported topics are identified
+  rm(list = ls(envir = mddata), envir = mddata)
+  expect_equal(
+    resolve_link_package("process", "testthat", test_path("testMdLinks")),
+    "processx"
+  )
+})
+
+test_that("resolve_link_package name clash", {
+  # skip in case pkgload/rlang changes this
+  skip_on_cran()
+  tag <- roxy_tag("title", NULL, NULL, file = "foo.R", line = 10)
+  expect_snapshot({
+    resolve_link_package("pkg_env", "roxygen2", test_path("testMdLinks2"), list(tag = tag))
+  })
+})
+
+test_that("is_reexported", {
+  expect_false(is_reexported("process", "processx"))
+  expect_true(is_reexported("process", "callr"))
+})
+
+test_that("find_reexport_source", {
+  expect_equal(find_reexport_source("process", "callr"), "processx")
+})
