@@ -123,3 +123,43 @@ test_that("custom family prefixes can be set", {
 
   expect_match(out$get_value("seealso"), "^Custom prefix:")
 })
+
+test_that("custom family prefixes can include Markdown", {
+
+  local_roxy_meta_set("rd_family_title", list(a = "Custom ***strongly emphasized*** prefix: "))
+  out <- roc_proc_text(rd_roclet(), "
+    #' foo
+    #' @family a
+    foo <- function() {}
+
+    #' bar
+    #' @family a
+    bar <- function() {}
+  ")[[1]]
+
+  expect_match(out$get_value("seealso"), "^Custom \\\\emph\\{\\\\strong\\{strongly emphasized\\}} prefix:")
+})
+
+test_that("careful ordering", {
+  out <- roc_proc_text(rd_roclet(), "
+    #' foo1
+    #' @family a
+    foo1 <- function() {}
+
+    #' foo2
+    #' @family a
+    foo2 <- function() {}
+
+    #' Foo3
+    #' @family a
+    Foo3 <- function() {}
+
+    #' foo
+    #' @family a
+    foo <- function() {}
+  ")
+
+  expect_snapshot({
+    out
+  })
+})
